library(lme4)
library(simr)

subj = factor(1:12)
cond = c("high", "low")
age = c(0.7257096,1.4514192,0.4838064,-0.4838064,-1.6933224,-1.4514192,-0.4838064,0.0000000,-0.9676128,0.7257096,1.4514192,0.2419032)
item = factor(1:16)

subj_full = rep(subj,16)
cond_full = rep(rep(cond, each=12, 8))
age_full = rep(age,16)
item_full = rep(rep(item, each=12))

covars <- data.frame(Subjects=as.character(subj_full), condition=cond_full, age=age_full, Items = item_full)

##run glmer w/ optimizer=c("bobyqa") to get intercepts, slopes, residual variance
m1 = glmer(Uninversion ~ Condition * Age + (1|Subject) + (1|Items), data=Data, family="binomial", optimizer=c("bobyqa"))

## Intercept and slope for Condition : 0.363 is the small effect size assumed for Condition, so we replace that slope
fixed <- c(-2.42,0.363,-1.43,0.7368)

## Random intercepts for participants
res_var <- list(0.011,5.5)

model <- makeGlmer(y ~ condition * age + (1|Subjects) + (1|Items), fixef=fixed, VarCorr=res_var, data=covars, family = "binomial")

model

#fcompare(y~age) allows us to specify that we're interested in Condition w/ the power analysis
sim_condition <- powerSim(model, nsim=100,fcompare(y~age))

sim_condition

#extend the analysis to include a simulated n subjects (in this case, 60)
model_ext_subj <- extend(model, along="Subjects", n=60)

sim_ext_subj <- powerSim(model_ext_subj, nsim=100, fcompare(y~age))
sim_ext_subj
